package com.isu.gaswellwatch.modbus.data.decode.impl;

import com.isu.gaswellwatch.modbus.data.ModbusMessage;
import com.isu.gaswellwatch.modbus.data.decode.DecodeHandler;
import org.apache.commons.lang3.StringUtils;
import org.apache.commons.lang3.math.NumberUtils;
import org.springframework.stereotype.Component;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Map;

/**
 * 本地日期时间类型解析器，year + 2000
 *
 * @author <a href="mailto:scwsl@foxmail.com">王仕龙</a>
 * 2024/12/10 12:25
 */
@Component(Base2000YearLocalDateTimeDecodeHandler.NAME + DecodeHandler.DECODE_NAME)
public class Base2000YearLocalDateTimeDecodeHandler implements DecodeHandler {
    public static final String NAME = "base2000YearLocalDateTime";

    public static final DateTimeFormatter IN_FORMATTER = DateTimeFormatter.ofPattern("yyyy-M-d H:m:s");
    public static final DateTimeFormatter OUT_FORMATTER = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");


    @Override
    public String decode(Map<String, Object> commandPointMap, String value) {
        if (StringUtils.isBlank(value)) {
            return value;
        }
        String[] splitValues = value.split(" ");
        String[] dateValues = splitValues[0].split("-");
        String year = dateValues[0];
        if (NumberUtils.isCreatable(year)) {
            year = String.valueOf(NumberUtils.createLong(year) + 2000);
        }
        value = StringUtils.join(year, "-", dateValues[1], "-", dateValues[2], " ", splitValues[1]);
        return LocalDateTime.parse(value, IN_FORMATTER).format(OUT_FORMATTER);
    }

    @Override
    public void decode(Map<String, Object> commandPointMap, ModbusMessage.MessagePoint point) {
        point.setValue(this.decode(commandPointMap, point.getValue()));
    }

}
